@@ -29,6 +29,7 @@ def main():
     group = parser.add_argument_group("Logging").add_mutually_exclusive_group()
     group.add_argument(
         "-v",
+        "--verbose",
         action="store_true",
         help=f"Enable INFO level logging.",
     )
@@ -84,7 +85,6 @@ def main():
     )
 
     args = parser.parse_args()
-    print(args)
 
     root_path = args.root_path[0] if args.root_path else None
 
