@@ -21,7 +21,7 @@ def create_temp_dir(parent_dir: Path) -> Path:  # tempfile.TemporaryDirectory:
         parent_dir / f"{datetime.datetime.now().strftime('%Y-%m-%d_%H-%M')}"
         f"_{randomized_name}"
     )
-    temp_dir.mkdir()
+    temp_dir.mkdir(parents=True)
 
     return temp_dir
 
